pub struct LimitStatus {
pub limits: SpendingLimits,
pub hourly_spent: Money,
pub daily_spent: Money,
pub monthly_spent: Money,
}Expand description
Current-session spend and configured limits for all three UTC periods.
Fields
limits: SpendingLimitsActive limit configuration.
hourly_spent: MoneySession spend since the start of the current UTC hour.
daily_spent: MoneySession spend since the start of the current UTC day.
monthly_spent: MoneySession spend since the start of the current UTC month.